<?php

namespace Litepie\Example\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Example\Models\Permission;

class PermissionPolicy
{

    /**
     * Determine if the given user can view the permission.
     *
     * @param UserPolicy $user
     * @param Permission $permission
     *
     * @return bool
     */
    public function view(UserPolicy $user, Permission $permission)
    {
        if ($user->canDo('example.permission.view') && $user->isAdmin()) {
            return true;
        }

        return $permission->user_id == user_id() && $permission->user_type == user_type();
    }

    /**
     * Determine if the given user can create a permission.
     *
     * @param UserPolicy $user
     * @param Permission $permission
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('example.permission.create');
    }

    /**
     * Determine if the given user can update the given permission.
     *
     * @param UserPolicy $user
     * @param Permission $permission
     *
     * @return bool
     */
    public function update(UserPolicy $user, Permission $permission)
    {
        if ($user->canDo('example.permission.edit') && $user->isAdmin()) {
            return true;
        }

        return $permission->user_id == user_id() && $permission->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given permission.
     *
     * @param UserPolicy $user
     * @param Permission $permission
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Permission $permission)
    {
        return $permission->user_id == user_id() && $permission->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given permission.
     *
     * @param UserPolicy $user
     * @param Permission $permission
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Permission $permission)
    {
        if ($user->canDo('example.permission.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given permission.
     *
     * @param UserPolicy $user
     * @param Permission $permission
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Permission $permission)
    {
        if ($user->canDo('example.permission.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
